#
# spec file for package python-pyUSID
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global skip_python39 1
Name:           python-pyUSID
Version:        0.0.12
Release:        4.1
Summary:        Framework for processing scientific data (USID)
License:        MIT
URL:            https://pycroscopy.github.io/pyUSID/
Source0:        https://github.com/pycroscopy/pyUSID/archive/v%{version}.tar.gz#/pyUSID-%{version}.tar.gz
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module cytoolz}
BuildRequires:  %{python_module dask >= 0.10}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module h5py >= 2.6.0}
BuildRequires:  %{python_module ipywidgets >= 5.2.2}
BuildRequires:  %{python_module joblib >= 0.11.0}
BuildRequires:  %{python_module matplotlib >= 2.0.0}
BuildRequires:  %{python_module numpy >= 1.20 with %python-numpy < 2}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sidpy >= 0.10}
BuildRequires:  %{python_module toolz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-cytoolz
Requires:       python-dask >= 0.10
Requires:       python-h5py >= 2.6.0
Requires:       python-psutil
Requires:       python-sidpy >= 0.10
Requires:       python-toolz
Requires:       (python-numpy >= 1.20 with python-numpy < 2)
BuildArch:      noarch
%python_subpackages

%description
Framework for storing, visualizing, and processing Universal Spectroscopic
and Imaging Data (USID).

%prep
%autosetup -p1 -n pyUSID-%{version}
sed -i -e /pytest-runner/d -e /six/d setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#pycroscopy/pyUSID#80 for skips
%pytest -k 'not (test_custom_interp or test_single_default_interp or test_tuple_default_interp or test_normalize_and_default_interp)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pyUSID
%{python_sitelib}/py[Uu][Ss][Ii][Dd]-%{version}.dist-info

%changelog
* Tue Apr 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Support both lowercased and unnormalized metadata directory names.
* Tue Jul  9 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2.
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- skip python3.9 (numeric stack dependencies are gone)
* Fri Jan 26 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.0.12
  * Minor update to previous pyUSID version with changes to ensure
    compatibility with updated methods of slicing of h5 datasets in
    h5py. This also resolves the errors thrown by visualization
    utilizes that have plagued BGlib
- Release 0.0.11
  * This version maintains compatibility with the latest numpy, and
    also re-instates comp_utils that was removed from sidpy,
    causing version incompatibility. Furthermore, some dependency
    requirements have been updated. Whilst there are no feature
    improvements, this release ensures continued functionality of
    pyUSID.
- Drop pyUSID-pr84-np1.24.patch
- Drop abc_iterable.patch
* Sun Mar 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.0.10.post2
  * Minor release to fix failing functions with updated versions of
    pillow, and a minor bug fix to reshaping circumstance where
    there is only one position in a spectral dataset.
- Add pyUSID-pr84-np1.24.patch gh#pycroscopy/pyUSID#84
- Fix requirements
* Thu Oct 20 2022 pgajdos@suse.com
- python-six is not required
* Wed May  4 2022 Matej Cepl <mcepl@suse.com>
- Skip failing tests (gh#pycroscopy/pyUSID#80).
- Add abc_iterable.patch to make tests compatible
  (gh#pycroscopy/pyUSID#81).
* Sat Feb  5 2022 Ben Greiner <code@bnavigator.de>
- Disable python310 build: No dask yet
* Tue Dec 14 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed May 12 2021 andy great <andythe_great@pm.me>
- Update to version 0.0.10.
  * Minor bug fixes
  * Function that writes sidpy.Dataset to USID formatted HDF5 files.
  * Refactoring
  * Renamed numpy_translator to array_translator
  * Renamed write_utils to anc_build_utils
  * Separate module for Dimension
  * Removed unnecessary files like dtype_utils, io_utils
  * Updated imports to use sidpy instead of pyUSID
- Remove fix_tests_h5py-3.0.patch as it has been upstreamed.
* Wed Jan 20 2021 andy great <andythe_great@pm.me>
- Disable build for python36 because sidpy has no python36 build.
* Thu Dec 10 2020 andy great <andythe_great@pm.me>
- Add fix_tests_h5py-3.0.patch to fix broken test from h5py 3.0.
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.9.
  * Fixed bug regarding dask array transpose in USIDataset
  * Not writing region references for ancillary datasets anymore
  * Moved USID agnostic functions in pyUSID.io.reg_ref.py,
    pyUSID.io.dtype_utils.py, pyUSID.io.hdf_utils.simple.py,
    pyUSID.viz.plot_utils.py, pyUSID.viz.jupyter_utils.py,
    pyUSID.processing.comp_utils.py to new package - sidpy
  * Importing sidpy instead of local code copies for these modules
  * Enabling multiple instances of Process class to be executed in
    parallel via each MPI rank - ensemble / embarrassingly parallel
    processing
  * No longer pushing tests when deploying via pip
- Remove fix_tests_dir_in_site_package.patch
* Mon Aug 17 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the download url
* Thu Aug  6 2020 andy great <andythe_great@pm.me>
- Initial package release.
